summaryrefslogtreecommitdiffstats
path: root/sys/ufs
diff options
context:
space:
mode:
authordds <dds@FreeBSD.org>2005-10-12 06:56:00 +0000
committerdds <dds@FreeBSD.org>2005-10-12 06:56:00 +0000
commit0fb2e655fdaa468d5188d6e87ef07cb383149b5b (patch)
treeb831f3d94b8f98284035c19c12732a3f1465d75b /sys/ufs
parent66b195cfae1820593765c34e4917eb3a71d0204f (diff)
downloadFreeBSD-src-0fb2e655fdaa468d5188d6e87ef07cb383149b5b.zip
FreeBSD-src-0fb2e655fdaa468d5188d6e87ef07cb383149b5b.tar.gz
Move execve's access time update functionality into a new
vfs_mark_atime() function, and use the new function for performing efficient atime updates in mmap(). Reviewed by: bde MFC after: 2 weeks
Diffstat (limited to 'sys/ufs')
-rw-r--r--sys/ufs/ufs/ufs_vnops.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/ufs/ufs/ufs_vnops.c b/sys/ufs/ufs/ufs_vnops.c
index 9a04787..b26756c 100644
--- a/sys/ufs/ufs/ufs_vnops.c
+++ b/sys/ufs/ufs/ufs_vnops.c
@@ -437,13 +437,13 @@ ufs_setattr(ap)
return (EINVAL);
}
/*
* Update the file's access time when it has been executed. We are
* doing this here to specifically avoid some of the checks done
* below -- this operation is done by request of the kernel and
* should bypass some security checks. Things like read-only
* checks get handled by other levels (e.g., ffs_update()).
*/
- if (vap->va_vaflags & VA_EXECVE_ATIME) {
+ if (vap->va_vaflags & VA_MARK_ATIME) {
ip->i_flag |= IN_ACCESS;
return (0);
}
@@ -437,13 +437,13 @@ ufs_setattr(ap)
}
/*
- * Update the file's access time when it has been executed. We are
- * doing this here to specifically avoid some of the checks done
+ * Mark for update the file's access time for vfs_mark_atime().
+ * We are doing this here to avoid some of the checks done
* below -- this operation is done by request of the kernel and
* should bypass some security checks. Things like read-only
OpenPOWER on IntegriCloud